@@ -57,7 +57,7 @@ import pickle
 #####used to assess volumetric change.                  ########
 ################################################################
 
-def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
+def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror, beachlength):
         """
         Identifies the masked DEM's in directory and iterates through them performing
         Elevation models of difference. Allows DEM's of different sizes within the 
@@ -82,7 +82,7 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
         num = (len(sorted(glob.glob(path+"*masked.tif")))-1)
         print(num)
         DODdic = {}
-        # print(maskglob)
+        
         for i in maskglobresults:
             for count in range(0,len(maskglobresults[0])):
         ###use the counter to index the mask glob results list [0]
@@ -91,8 +91,8 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                     newer = rio.open(i[count+1])
 
 
-                    date1 = (i[count][-16:-10])
-                    date2 = (i[count+1][-16:-10])
+                    date1 = (i[count][-18:-10])
+                    date2 = (i[count+1][-18:-10])
 
                     new = np.array(newer.read(1),dtype = rasterio.float32)             
                     old = np.array(older.read(1),dtype = rasterio.float32)
@@ -139,7 +139,7 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                           show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) \
                              # title = 'DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]))
                             
-                          ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)     
+                          ax.set_title('DOD %s - %s' %(date1[6:9]+'/'+date1[4:6]+"/"+date1[0:4], date2[6:9]+'/'+date2[4:6]+"/"+date2[0:4]),fontsize=10)     
                           cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax=ax)
                           cbar.set_label('Elevation Change (m)',rotation=270, labelpad=10)
            
@@ -157,6 +157,12 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                           ##LoD
                           lods = np.ma.masked_where((-abs(measurementerror) < vols) & (vols < measurementerror), vols)
                           print("\nThe total volume of change including Limit of Detection is \n", np.sum(lods), "\n(m3)\n")
+                          ##Normalised Change Per Beach Width
+                          dQnet = 1/beachlength * np.sum(vols)
+                          print("\n Net Volume Change Per Unit Beach Width \n",dQnet, "\n(m3 m-1)\n")
+                          ##Gross change per unit (total)
+                          dQgross = 1/beachlength * (np.sum(abs(lidardem1)*pixelsize))
+                          print("\n Gross Volume Change Per Unit Beach Width \n", dQgross, "\n(m3 m-1)\n")
                         
                         
                     elif new.shape < old.shape:
@@ -220,7 +226,7 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                           show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) \
 
                                
-                          ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)      
+                          ax.set_title('DOD %s - %s' %(date1[6:9]+'/'+date1[4:6]+"/"+date1[0:4], date2[6:9]+'/'+date2[4:6]+"/"+date2[0:4]),fontsize=10)      
                           cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax =ax)
                           cbar.set_label('Elevation Change (m)',rotation=270)
                           
@@ -237,7 +243,16 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                           print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
                           
                           lods = np.ma.masked_where((-abs(measurementerror) < vols) & (vols < measurementerror), vols)
+                          
                        	  print("\nThe total volume of change including Limit of Detection is \n", np.sum(lods), "\n(m3)\n")
+                       	  
+                       	  ##Normalised Change Per Beach Width
+                          dQnet = 1/beachlength * np.sum(vols)
+                          print("\n Net Volume Change Per Unit Beach Width \n", dQnet, "\n(m3 m-1)\n")
+                          
+                          ##Gross change per unit (total)
+                          dQgross = 1/beachlength * (np.sum(abs(lidardem1)*pixelsize))
+                          print("\n Gross Volume Change Per Unit Beach Width \n", dQgross, "\n(m3 m-1)\n")
 
                           ##if newer shape is bigger than the older shape 
                     elif new.shape > old.shape:   
@@ -263,7 +278,7 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
 
                           out_meta.update({'driver':'GTiff', 'count':1,'height':older.shape[0],'width':older.shape[1],'transform':out_transform})
                        
-                          with rio.open(save_to_path+'/'+date1+date2+'bounding.tif','w', **out_meta) as dest:
+                          with rio.open(path+'/'+date1+date2+'bounding.tif','w', **out_meta) as dest:
                                   dest.crs = rasterio.crs.CRS.from_epsg(DODCRS)
                                   dest.write(out_image)
                                   
@@ -294,12 +309,15 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                           lidardem1 = np.array(lidardem.read(1))
                           lidardem1 = np.ma.array(lidardem1, mask=(mask))
                           
+                          
+                          
+                          
                           fig = matplotlib.pyplot.figure()
                           ax = fig.add_subplot(1,1,1)     
                           
                           norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                           show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) 
-                          ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)         
+                          ax.set_title('DOD %s - %s' %(date1[6:9]+'/'+date1[4:6]+"/"+date1[0:4], date2[6:9]+'/'+date2[4:6]+"/"+date2[0:4]),fontsize=10)         
                           cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                           cbar.set_label('Elevation Change (m)', rotation=270)
 
@@ -313,13 +331,22 @@ def DEMofDifference(path, DODCRS, save_to_path, pixelsize, measurementerror):
                           ##Vol Change    
                           vols = lidardem1 * pixelsize
                           print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
+                          
+                          ##Lods
                           lods = np.ma.masked_where((-abs(measurementerror) < vols) & (vols < measurementerror), vols)
                           print("\nThe total volume of change including Limit of Detection is \n", np.sum(lods), "\n(m3)\n")
+                          
+                          ##Normalised Change Per Beach Width
+                          dQnet = 1/beachlength * np.sum(vols)
+                          print("\n Net Volume Change Per Unit Beach Width \n", dQnet, "\n(m3 m-1)\n")
                     	  
-                    	
+                    	  ##Gross change per unit (total)
+                          dQgross = 1/beachlength * (np.sum(abs(lidardem1)*pixelsize))
+                          print("\n Gross Volume Change Per Unit Beach Width \n", dQgross, "\n(m3 m-1)\n")	
                           ## SAVE PANDAS FRAME. 
-
-                    DODdic[date1+'-'+date2] = {'Volumes': np.sum(vols),'LoD Vol':np.sum(lods), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]}
+					
+                    DODdic[date1+'-'+date2] = {'Volumes': np.sum(vols),'LoD Vol':np.sum(lods), 'Net Vol Change Per Unit Width': dQnet,
+                    							'Gross Volume Change per Unit':dQgross,'Date': datetime.strptime((date2[6:9]+'-'+date2[4:6]+'-'+date2[0:4]),'%d-%m-%Y')}
                 else:
                         break
         with open (save_to_path+'/DODdic.pkl', 'wb') as fb:
