@@ -13,7 +13,6 @@ from rasterio.plot import show , show_hist
 import glob
 
 import fiona
-# import rioxarray
 
 import geopandas as gpd
 from geopandas import GeoSeries, GeoDataFrame
@@ -68,16 +67,19 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
                 
                 Returns
                 -------
-                Series of elevation dfference models along with model difference graphs. 
+                Series of elevation difference models along with model difference graphs. 
                 """
                 maskglobresults = [sorted(glob.glob(path+"*masked.tif"))]
+                
                 num = (len(sorted(glob.glob(path+"*masked.tif")))-1) 
                 seasonfile = []
                 for i in maskglobresults[0]:
-                    if re.search('[0-9][0-9][0-9][0-9][0-0][9-9]masked.tif',i):
+                    if re.search('[1-2][0-9][0-9][0-9][0-0][9-9][0-9][0-9]masked.tif',i):
                         seasonfile.append(i)
-                    elif re.search('[0-9][0-9][0-9][0-9][1-1][0-1]masked.tif',i):
-                        seasonfile.append(i)                    
+                        
+                    elif re.search('[1-2][0-9][0-9][0-9][1-1][0-1][0-9][0-9]masked.tif',i):
+                        seasonfile.append(i)  
+                                          
                     else:
                         continue
                    
@@ -87,12 +89,15 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
                 ###use the counter to index the mask glob results list [0]
                         if e < num:
                             
+                            
                             older = rio.open(i)
                             newer = rio.open(seasonfile[seasonfile.index(i)- len(seasonfile)+1])
                 
                 
-                            date1 = (i[-16:-10])
-                            date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-16:-10])
+                            date1 = (i[-18:-10])
+                            
+                            date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-18:-10])
+                            
                             
                             new = np.array(newer.read(1),dtype = rasterio.float32)             
                             old = np.array(older.read(1),dtype = rasterio.float32)
@@ -137,7 +142,7 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
                                 
                                 show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform)
                                 
-                                ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)
+                                ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)
                                 cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                 cbar.set_label('Elevation Change (m)',rotation=270, labelpad=10)
                                 plt.tight_layout()
@@ -214,7 +219,7 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
 
                                   norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                                   show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,)
-                                  ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)
+                                  ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)
 
                                   cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                   cbar.set_label('Elevation Change (m)',rotation=270)
@@ -231,7 +236,7 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
 
                             elif new.shape > old.shape:   
      
-                                  print('elif2')
+                                  
                                     ##Older bounding box shape
                                   x = np.empty(older.read(1).shape, dtype = rasterio.float32)
                                   
@@ -290,7 +295,7 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
                                   norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()) )                        
                                   show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) 
                                        
-                                  ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)    
+                                  ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)    
                                   cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                   cbar.set_label('Elevation Change (m)', rotation=270)
                                   plt.tight_layout()
@@ -304,8 +309,8 @@ def autumnDOD(path, pixelsize, save_to_path, DODCRS):
                                   vols = lidardem1 * pixelsize
                                   print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
                 
-                                  
-                            autumndic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]}
+                                 
+                            autumndic[date1+'-'+date2] = {'Volumes': np.sum(vols),'Date':date2[6:8]+"-"+date2[4:6]+"-"+date2[0:4]} 
                         else:
                                 break    
                 with open (save_to_path+'/autumndic.pkl', 'wb') as fb:
@@ -337,7 +342,7 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                 seasonfile = []
                 for i in maskglobresults[0]:
 
-                    if re.search('[0-9][0-9][0-9][0-9][0-1][1-2]masked.tif',i):
+                    if re.search('[0-9][0-9][0-9][0-9][0-1][1-2][0-9][0-9]masked.tif',i):
                         seasonfile.append(i)
                     else:
                         continue
@@ -351,8 +356,8 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                             newer = rio.open(seasonfile[seasonfile.index(i)- len(seasonfile)+1])
                 
                 
-                            date1 = (i[-16:-10])
-                            date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-16:-10])
+                            date1 = (i[-18:-10])
+                            date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-18:-10])
                 
                             new = np.array(newer.read(1),dtype = rasterio.float32)             
                             old = np.array(older.read(1),dtype = rasterio.float32)
@@ -396,7 +401,7 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                           
                                 norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                                 show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,)
-                                ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)  
+                                ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)  
 
                                 cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                 cbar.set_label('Elevation Change (m)',rotation=270, labelpad=10)
@@ -413,7 +418,7 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                                 print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
  
                             elif new.shape < old.shape:
-                                  print('elif 1')
+                                  
                                   ## Use the bounding box of the newer raster - making shapefile to clip by
                                   
                                   boundbox  = newer.bounds
@@ -472,7 +477,7 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                                   norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                                   show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) 
 
-                                  ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)     
+                                  ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)     
                                   cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                   plt.xticks(size = 5)
                                   plt.yticks(size = 5)
@@ -546,7 +551,7 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                                   norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                                   show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) 
 
-                                  ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)
+                                  ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)
                                   cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                   cbar.set_label('Elevation Change (m)', rotation=270)
                                   plt.tight_layout()
@@ -560,7 +565,7 @@ def winterDOD(path, pixelsize, save_to_path, DODCRS):
                                   vols = lidardem1 * pixelsize
                                   print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
                             
-                            winterdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]} 
+                            winterdic[date1+'-'+date2] = {'Volumes': np.sum(vols),  'Date':date2[6:8]+"-"+date2[4:6]+"-"+date2[0:4]} 
                         else:
                             break
                 with open (save_to_path+'/winterdic.pkl', 'wb') as fb:
@@ -575,7 +580,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
         num = (len(sorted(glob.glob(path+"*masked.tif")))-1) 
         seasonfile = []
         for i in maskglobresults[0]:            
-            if re.search('[0-9][0-9][0-9][0-9][0-0][3-5]masked.tif',i):
+            if re.search('[0-9][0-9][0-9][0-9][0-0][3-5][0-9][0-9]masked.tif',i):
                 seasonfile.append(i)
             else:
                 continue
@@ -589,8 +594,8 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
                     newer = rio.open(seasonfile[seasonfile.index(i)- len(seasonfile)+1])
         
         
-                    date1 = (i[-16:-10])
-                    date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-16:-10])
+                    date1 = (i[-18:-10])
+                    date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-18:-10])
                     
                     new = np.array(newer.read(1),dtype = rasterio.float32)             
                     old = np.array(older.read(1),dtype = rasterio.float32)
@@ -631,7 +636,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
                         norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                         show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform) 
                             
-                        ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]), fontsize=10)
+                        ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]), fontsize=10)
                         cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                         cbar.set_label('Elevation Change (m)',rotation=270, labelpad=10)
                         plt.tight_layout()
@@ -647,7 +652,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
 
 
                     elif new.shape < old.shape:
-                          print('elif 1')
+                          
                           ## Use the bounding box of the newer raster - making shapefile to clip by
                           
                           boundbox  = newer.bounds
@@ -708,7 +713,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
                           
                           norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                           show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,)
-                          ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)
+                          ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)
 
                           cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                           cbar.set_label('Elevation Change (m)',rotation=270)
@@ -725,7 +730,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
 
                     elif new.shape > old.shape:   
 
-                          print('elif2')
+                          
                             ##Older bounding box shape
                           x = np.empty(older.read(1).shape, dtype = rasterio.float32)
                           
@@ -784,7 +789,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
                           norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()) )                        
                           show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) 
 
-                          ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)    
+                          ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)    
                           cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                           cbar.set_label('Elevation Change (m)', rotation=270)
                           plt.tight_layout()
@@ -799,7 +804,7 @@ def springDOD(path, pixelsize, save_to_path, DODCRS):
                           print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
         
                           
-                    Springdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]}
+                    Springdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':date2[6:8]+"-"+date2[4:6]+"-"+date2[0:4]} 
                 else:
                         break    
         with open (save_to_path+'/Springdic.pkl', 'wb') as fb:
@@ -817,7 +822,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                 seasonfile = []
                 for i in maskglobresults[0]:
 
-                    if re.search('[0-9][0-9][0-9][0-9][0-0][6-8]masked.tif',i):
+                    if re.search('[0-9][0-9][0-9][0-9][0-0][6-8][0-9][0-9]masked.tif',i):
                         seasonfile.append(i)
                     else:
                         continue
@@ -832,8 +837,8 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                             newer = rio.open(seasonfile[seasonfile.index(i)- len(seasonfile)+1])
                 
                 
-                            date1 = (i[-16:-10])
-                            date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-16:-10])
+                            date1 = (i[-18:-10])
+                            date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-18:-10])
                 
                             new = np.array(newer.read(1),dtype = rasterio.float32)             
                             old = np.array(older.read(1),dtype = rasterio.float32)
@@ -874,7 +879,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                           
                                 norm = matplotlib.colors.TwoSlopeNorm(vmin = int(lidardem1.min()), vcenter = 0, vmax= int(lidardem1.max()))
                                 show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,)
-                                ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)     
+                                ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)     
 
                                 cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                 cbar.set_label('Elevation Change (m)',rotation=270, labelpad=10)
@@ -890,7 +895,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                                 print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
      
                             elif new.shape < old.shape:
-                                  print('elif 1')
+                                  
                                   ## Use the bounding box of the newer raster - making shapefile to clip by
                                   
                                   boundbox  = newer.bounds
@@ -951,7 +956,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                                   
                                   norm = matplotlib.colors.TwoSlopeNorm(vmin = lidardem1.min(), vcenter = 0, vmax= lidardem1.max())
                                   show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,) 
-                                  ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)    
+                                  ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)    
                                   cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                   plt.xticks(size = 5)
                                   plt.yticks(size = 5)
@@ -966,7 +971,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
 
                             elif new.shape > old.shape:   
                                 
-                                  print('elif2')
+                                  
                                     ##Older bounding box shape
                                   x = np.empty(older.read(1).shape, dtype = rasterio.float32)
                                   
@@ -1021,7 +1026,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                             
                                   norm = matplotlib.colors.TwoSlopeNorm(vmin = lidardem1.min(), vcenter = 0, vmax= lidardem1.max())
                                   show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform,)
-                                  ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)     
+                                  ax.set_title('DOD %s - %s' %(date1[6:8]+"/"+date1[4:6]+"/"+date1[0:4], date2[6:8]+"/"+date2[4:6]+"/"+date2[0:4]),fontsize=10)     
 
                                   cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
                                   cbar.set_label('Elevation Change (m)', rotation=270)
@@ -1037,7 +1042,7 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                                   print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
                                   
                                   
-                            summerdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]} 
+                            summerdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':date2[6:8]+"-"+date2[4:6]+"-"+date2[0:4]} 
                         else:
                                 break
                 with open (save_to_path+'/summerdic.pkl', 'wb') as fb:
@@ -1045,226 +1050,3 @@ def summerDOD(path, pixelsize, save_to_path, DODCRS):
                 DOD  = pd.DataFrame(summerdic)
                 DOD = DOD.T
                 return  DOD   
-#%%
-def autumnDOD(path, pixelsize, save_to_path, DODCRS):
-            maskglobresults = [sorted(glob.glob(path+"*masked.tif"))]
-            
-            num = (len(sorted(glob.glob(path+"*masked.tif")))-1) 
-            seasonfile = []
-            for i in maskglobresults[0]:
-                
-                if re.search('[0-9][0-9][0-9][0-9][0-0][9-9]masked.tif',i):
-                    seasonfile.append(i)
-                elif re.search('[0-9][0-9][0-9][0-9][1-1][0-1]masked.tif',i):
-                    seasonfile.append(i)                    
-                else:
-                    continue
-            num = (len(seasonfile)-1)
-            DODdic = {}
-            for e, i in enumerate(seasonfile):
-            ###use the counter to index the mask glob results list [0]
-                    if e < num:
-                        
-                        older = rio.open(i)
-                        newer = rio.open(seasonfile[seasonfile.index(i)- len(seasonfile)+1])
-            
-            
-                        date1 = (i[-16:-10])
-                        date2 = (seasonfile[seasonfile.index(i)- len(seasonfile)+1][-16:-10])
-            
-                        new = np.array(newer.read(1),dtype = rasterio.float32)             
-                        old = np.array(older.read(1),dtype = rasterio.float32)
-            
-                
-                        if old.shape == new.shape: 
-                            
-                             ###MASK AND SUB FUNC
-                        
-                              x = np.empty(newer.read(1).shape, dtype = rasterio.float32)
-            
-                              imagenewmask = np.ma.array(new, mask = ((new == -9999.0)|(new == 0.0)))
-                              imageoldmask = np.ma.array(old, mask = ((old == -9999.0)|(old == 0.0)))
-                             
-                              mask1 = np.ma.getmask(imagenewmask)
-                              mask2 = np.ma.getmask(imageoldmask)
-                        
-                              mask = np.logical_or(mask1,mask2)
-            
-                              x = np.where(((imagenewmask != 0.0)&(imageoldmask != 0.0)), imagenewmask - imageoldmask, x)
-                              
-                              x = np.ma.array(x, mask = (mask))
-                            
-                              out_meta = newer.meta
-                              with rio.open(path+date1+date2+'autumn.tif','w',**out_meta) as dest:
-                                    dest.write(x.filled(fill_value = -9999.0), 1)
-                                    dest.crs = rasterio.crs.CRS.from_epsg(DODCRS)
-
-                            
-                            ###PLOT FUNC
-                             
-                              lidardem = rio.open(path+date1+date2+'autumn.tif')
-                              lidardem1 = np.array(lidardem.read(1))
-                              lidardem1 = np.ma.array(lidardem1, mask=(mask))
-                            
-
-                              fig = matplotlib.pyplot.figure()
-                              ax = fig.add_subplot(1,1,1)
-                      
-                              norm = matplotlib.colors.TwoSlopeNorm(vmin = lidardem1.min(), vcenter = 0, vmax= lidardem1.max())
-                              show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm,transform = lidardem.transform,)
-
-                              ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10)    
-                              cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
-                              
-                              plt.xticks(size = 5)
-                              plt.yticks(size = 5)
-                              plt.show()
-                              show_hist(lidardem1, bins=10, histtype='stepfilled', lw=0.0, stacked=True, alpha=0.3)
-                              fig.savefig(save_to_path+'/'+date1+date2+'autumn.png')
-                              
-                              vols = lidardem1 * pixelsize
-                              print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n") 
-                              DODdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]} 
-
-                        elif new.shape < old.shape:
-                              print('elif 1')
-                              ## Use the bounding box of the newer raster - making shapefile to clip by
-                              
-                              boundbox  = newer.bounds
-                              geom = box(*boundbox)
-                              df = gpd.GeoDataFrame({'id':1,'geometry':[geom]})
-                              df = df.set_crs(DODCRS)
-                              #   ###Shapefile
-                              df.to_file(path+'boundary.shp')
-                              with fiona.open(path+'boundary.shp','r') as shapefile:
-                                    shapes = [feature['geometry'] for feature in shapefile]
-         
-                                ###Clip older mask by newer shapefile
-                              out_image, out_transform = rasterio.mask.mask(older, shapes, crop=True, filled = True,  nodata = -9999.0)
-                              out_meta = newer.meta
-            
-                              out_meta.update({'driver':'GTiff',"count":1, 'height':newer.shape[0],'width':newer.shape[1],'transform':out_transform})
-                              ###maybe change height according to new shape and old shape.
-                                
-                              with rio.open(path+date1+date2+'bounding.tif','w', **out_meta) as dest:
-                                      dest.crs = rasterio.crs.CRS.from_epsg(DODCRS)
-                                      dest.write(out_image)
-                                      
-                              olderimage = rio.open(path+date1+date2+'bounding.tif')
-                              old = np.array(olderimage.read(1),dtype = rasterio.float32)
-                                           
-                              imagenewmask = np.ma.array(new, mask = (new == -9999.0))
-                              imagenewmask = np.ma.array(imagenewmask, mask = (imagenewmask == 0.0))
-                           
-                              imageoldmask = np.ma.array(old, mask = (old == -9999.0))
-                              imageoldmask = np.ma.array(imageoldmask, mask = (imageoldmask == 0.0))
-             
-                              mask1 = np.ma.getmask(imagenewmask)
-                              mask2 = np.ma.getmask(imageoldmask)
-                        
-                              mask = np.logical_or(mask1,mask2)
-                              
-                              x = np.empty(newer.read(1).shape, dtype = rasterio.float32)
-            
-                              x = np.where(((~imagenewmask.mask)&(~imageoldmask.mask)), imagenewmask - imageoldmask, x)
-                              x = np.ma.array(x, mask = (mask))
-                              with rio.open(path+date1+date2+'autumn.tif','w',**out_meta) as dest:
-                                  dest.write(x.filled(fill_value = -9999.0), 1)
-                                  
-                              lidardem = rio.open(path+date1+date2+'autumn.tif')
-                              
-                              lidardem1 = np.array(lidardem.read(1))
-             
-                              lidardem1 = np.ma.array(lidardem1, mask=(mask))
-                              fig, ax = plt.subplots(1, figsize=(5,5)) 
-                              
-                              
-                              norm = matplotlib.colors.TwoSlopeNorm(vmin = lidardem1.min(), vcenter = 0, vmax= lidardem1.max())
-                              show((lidardem1) , ax = ax, cmap='seismic_r', norm = norm, transform = lidardem.transform,)
-                              ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10) 
-                              cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
-                              plt.xticks(size = 5)
-                              plt.yticks(size = 5)
-                              plt.show()
-                              show_hist(lidardem1, bins=10, histtype='stepfilled', lw=0.0, stacked=True, alpha=0.3)
-                              fig.savefig(save_to_path+'/'+date1+date2+'autumn.png')
-                              
-                              vols = lidardem1 * pixelsize
-                              print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
-                              DODdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]} 
-
-                        elif new.shape > old.shape:   
-                            
-                              print('elif2')
-                                ##Older bounding box shape
-                              x = np.empty(older.read(1).shape, dtype = rasterio.float32)
-                              
-                              boundbox  = older.bounds
-                              geom = box(*boundbox)
-                              df = gpd.GeoDataFrame({'id':1,'geometry':[geom]})
-                              df = df.set_crs(DODCRS)
-                              df.to_file(path+'boundary.shp')
-                              with fiona.open(path+'boundary.shp','r') as shapefile:
-                                  shapes = [feature['geometry'] for feature in shapefile]
-                                  
-            
-                              out_image, out_transform = rasterio.mask.mask(newer, shapes, crop=True, filled = True, nodata = -9999.0)
-                              
-                              out_meta = older.meta
-            
-                              out_meta.update({'driver':'GTiff','count':1, 'height':older.shape[0],'width':older.shape[1],'transform':out_transform})
-                           
-                              with rio.open(path+date1+date2+'bounding.tif','w', **out_meta) as dest:
-                                      dest.crs = rasterio.crs.CRS.from_epsg(DODCRS)
-                                      dest.write(out_image)
-                                      
-                              newerimage = rio.open(path+date1+date2+'bounding.tif')
-                              
-                              new = np.array(newerimage.read(1),dtype = rasterio.float32)
-                              
-                              imagenewmask = np.ma.array(new, mask = (new == -9999.0))
-                              imagenewmask = np.ma.array(imagenewmask, mask = (imagenewmask == 0.0))
-            
-                              imageoldmask = np.ma.array(old, mask = (old == -9999.0))
-                              imageoldmask = np.ma.array(imageoldmask, mask = (imageoldmask == 0.0))
-            
-
-                              mask1 = np.ma.getmask(imagenewmask)
-                              mask2 = np.ma.getmask(imageoldmask)
-                        
-                              mask = np.logical_or(mask1,mask2)
-            
-                              x = np.where(((~imagenewmask.mask)&(~imageoldmask.mask)), imagenewmask - imageoldmask, x)
-            
-                              x = np.ma.array(x, mask = (mask))
-            
-                              with rio.open(path+date1+date2+'autumn.tif','w',**out_meta) as dest:
-                                  dest.write(x.filled(fill_value = -9999.0), 1)    
-                              
-                              lidardem = rio.open(path+date1+date2+'autumn.tif')
-                              
-                              
-                              lidardem1 = np.array(lidardem.read(1))
-                              masky = lidardem.read_masks(1)
-            
-                              lidardem1 = np.ma.array(lidardem1, mask=(mask))
-                              
-                              fig, ax = plt.subplots(1, figsize=(5,5)) 
-                        
-                              norm = matplotlib.colors.TwoSlopeNorm(vmin = lidardem1.min(), vcenter = 0, vmax= lidardem1.max())
-                              show((lidardem1) , ax = ax, cmap='seismic_r',norm = norm, transform = lidardem.transform)
-                              ax.set_title('DOD %s - %s' %(date1[4:7]+"/"+date1[0:4], date2[4:7]+"/"+date2[0:4]),fontsize=10) 
-                              cbar = plt.colorbar(cm.ScalarMappable(norm=norm, cmap = 'seismic_r'), ax = ax)
-                              plt.xticks(size = 5)
-                              plt.yticks(size = 5)
-                              plt.show()
-                              show_hist(lidardem1, bins=10, histtype='stepfilled', lw=0.0, stacked=True, alpha=0.3)
-                              fig.savefig(save_to_path+'/'+date1+date2+'autumn.png')
-                              
-                              vols = lidardem1 * pixelsize
-                              print("\nThe total volume of change is \n", np.sum(vols), "\n(m3)\n")
-                              DODdic[date1+'-'+date2] = {'Volumes': np.sum(vols), 'Date':['%s - %s' %(date1[4:7]+'/'+date1[0:4], date2[4:7]+'/'+date2[0:4])]} 
-
-            DOD  = pd.DataFrame(DODdic)
-            DOD = DOD.T
-            return  DOD  
\ No newline at end of file
